﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using LayoutTransformControlSample;

namespace LayoutTransformControlSilverlight
{
    public partial class Page : UserControl
    {
        // Global transformation
        private ScaleTransform _scaleTransform = new ScaleTransform();
        private SkewTransform _skewTransform = new SkewTransform();
        private RotateTransform _rotateTransform = new RotateTransform();

        // Collection of LayoutTransformControls
        private IEnumerable<LayoutTransformControl> _layoutTransformControls;

        // Protects ValueChanged handler during InitializeComponent
        private bool _initializeComponentFinished;

        public Page()
        {
            // Initialize component
            InitializeComponent();
            _initializeComponentFinished = true;

            // Create test elements
            var transformGroup = new TransformGroup();
            transformGroup.Children.Add(_scaleTransform);
            transformGroup.Children.Add(_skewTransform);
            transformGroup.Children.Add(_rotateTransform);
            _layoutTransformControls = LayoutTransformControlTesting.CreateTestMatrix(TestMatrix, transformGroup);

            // Show initial value
            Slider_ValueChanged(null, null);
        }

        private void Slider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            if (_initializeComponentFinished)
            {
                // Update transformations
                _scaleTransform.ScaleX = scaleXSlider.Value;
                _scaleTransform.ScaleY = scaleYSlider.Value;
                _skewTransform.AngleX = skewXSlider.Value;
                _skewTransform.AngleY = skewYSlider.Value;
                _rotateTransform.Angle = rotateSlider.Value;

                // Update displays
                scaleXDisplay.Text = Math.Round(scaleXSlider.Value, 2).ToString(CultureInfo.CurrentCulture);
                scaleYDisplay.Text = Math.Round(scaleYSlider.Value, 2).ToString(CultureInfo.CurrentCulture);
                skewXDisplay.Text = Math.Round(skewXSlider.Value, 2).ToString(CultureInfo.CurrentCulture);
                skewYDisplay.Text = Math.Round(skewYSlider.Value, 2).ToString(CultureInfo.CurrentCulture);
                rotateDisplay.Text = Math.Round(rotateSlider.Value, 2).ToString(CultureInfo.CurrentCulture);

                // Notify LayoutTransformControls
                foreach (var layoutTransformControl in _layoutTransformControls)
                {
                    layoutTransformControl.TransformUpdated();
                }
            }
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            var tag = (sender as FrameworkElement).Tag as string;
            if (string.IsNullOrEmpty(tag))
            {
                // Reset all values
                scaleXSlider.Value = 1;
                scaleYSlider.Value = 1;
                skewXSlider.Value = 0;
                skewYSlider.Value = 0;
                rotateSlider.Value = 0;
            }
            else
            {
                // Snap to the specified angle
                rotateSlider.Value = double.Parse(tag, CultureInfo.InvariantCulture);
            }
        }
    }
}
