﻿using System;
using System.Globalization;
using System.IO;
using System.Reflection;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Markup;
using System.Windows.Media.Imaging;

namespace Sample
{
    public partial class Page : UserControl
    {
        private const int SampleFontSizeLarge = 64;
        private const int SampleFontSizeSmall = 28;

        private bool _initializeComponentFinished;

        public Page()
        {
            InitializeComponent();
            _initializeComponentFinished = true;
            Slider_ValueChanged(null, null);
        }

        private void Slider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            if (_initializeComponentFinished)
            {
                scaleTransform.ScaleX = scaleXSlider.Value;
                scaleXDisplay.Text = Math.Round(scaleXSlider.Value, 2).ToString(CultureInfo.CurrentCulture);
                scaleTransform.ScaleY = scaleYSlider.Value;
                scaleYDisplay.Text = Math.Round(scaleYSlider.Value, 2).ToString(CultureInfo.CurrentCulture);
                skewTransform.AngleX = skewXSlider.Value;
                skewXDisplay.Text = Math.Round(skewXSlider.Value, 2).ToString(CultureInfo.CurrentCulture);
                skewTransform.AngleY = skewYSlider.Value;
                skewYDisplay.Text = Math.Round(skewYSlider.Value, 2).ToString(CultureInfo.CurrentCulture);
                rotateTransform.Angle = rotateSlider.Value;
                rotateDisplay.Text = Math.Round(rotateSlider.Value, 2).ToString(CultureInfo.CurrentCulture);
                layoutTransform.TransformUpdated();
            }
        }

        private void Empty_Click(object sender, RoutedEventArgs e)
        {
            layoutTransform.Child = null;
        }

        private void Text_Click(object sender, RoutedEventArgs e)
        {
            layoutTransform.Child = new TextBlock { Text = "TextBlock", FontSize = SampleFontSizeLarge };
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            layoutTransform.Child = new Button { Content = "Button", FontSize = SampleFontSizeLarge };
        }

        private void Image_Click(object sender, RoutedEventArgs e)
        {
            layoutTransform.Child = new Image { Source = new BitmapImage(new Uri("img10.jpg", UriKind.Relative)) };
        }

        private void Xaml_Click(object sender, RoutedEventArgs e)
        {
            using(var stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("Sample.XamlIcon.xaml"))
            {
                using(var reader = new StreamReader(stream))
                {
                    layoutTransform.Child = XamlReader.Load(reader.ReadToEnd()) as FrameworkElement;
                }
            }
        }

        private void ListBox_Click(object sender, RoutedEventArgs e)
        {
            var listBox = new ListBox();
            foreach (var item in "This-is a-fully-functional-ListBox!".Split('-'))
            {
                listBox.Items.Add(new ListBoxItem { Content = item, FontSize = SampleFontSizeSmall });
            }
            layoutTransform.Child = listBox;
        }
    }
}
